@@ -1,4 +1,4 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-import sec_to_hms
\ No newline at end of file
+__all__=[]
\ No newline at end of file
